@@ -11,8 +11,9 @@ use Test::BDD::Infrastructure::DNS;
 use Test::BDD::Infrastructure::Filesystem;
 use Test::BDD::Infrastructure::Swap;
 use Test::BDD::Infrastructure::Socket;
+use Test::BDD::Infrastructure::Exec;
 
-our $VERSION = '1.002'; # VERSION
+our $VERSION = '1.003'; # VERSION
 # ABSTRACT: a collection of step file definitions for Test Driven Infrastructure
 
 
@@ -30,7 +31,7 @@ Test::BDD::Infrastructure - a collection of step file definitions for Test Drive
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 Description
 
@@ -83,6 +84,10 @@ Check for testing swap space usage.
 
 Checks for tcp/udp/unix-socket based checks.
 
+=item L<Test::BDD::Infrastructure::Exec>
+
+Checks for executing commands and checking their output.
+
 =back
 
 =head1 Example
